--AH:ScriptId=BC97C20E-8F18-4797-B404-9B46F59B0BA0

WITH plans_cte ([Plan_Id], [Index_Number])
AS
(
SELECT [Plan_Id],
	   [Index_Number] = ROW_NUMBER() OVER(PARTITION BY [Application_Id], [PlanType_Code], [Plan_Name] ORDER BY [Plan_Id])
  FROM [Plans]
)
UPDATE P
   SET [Plan_Name] = [Plan_Name] + '-dup-' + CAST(F.[Index_Number] - 1 AS VARCHAR(MAX))
  FROM [Plans] P
       INNER JOIN plans_cte F
	           ON F.[Plan_Id] = P.[Plan_Id]
 WHERE F.[Index_Number] > 1;

GO

INSERT INTO [Rafts] ([Raft_Name]) VALUES ('Default')

DECLARE @Default_Raft_Id INT = SCOPE_IDENTITY()

INSERT INTO [RaftItems]
SELECT [Raft_Id] = @Default_Raft_Id,
       [Application_Id],
       [RaftItemType_Code] = CASE WHEN [PlanType_Code] = 'D' THEN 6 ELSE 3 END,
	   [RaftItem_Name] = [Plan_Name],
	   [Active_Indicator]
  FROM [Plans]

UNION ALL

SELECT [Raft_Id] = @Default_Raft_Id,
       [Application_Id],
	   [RaftItemType_Code] = 7,
	   [RaftItem_Name] = [Template_Name],
	   [Active_Indicator] = 'Y'
  FROM [TextTemplates]

UNION ALL

SELECT [Raft_Id] = @Default_Raft_Id,
       [Application_Id],
	   [RaftItemType_Code] = 8,
	   [RaftItem_Name] = [Pipeline_Name],
	   [Active_Indicator]
  FROM [Pipelines]

UNION ALL

SELECT [Raft_Id] = @Default_Raft_Id,
       [Application_Id],
	   [RaftItemType_Code] = 4,
	   [RaftItem_Name] = [ScriptAsset_Name],
	   [Active_Indicator] = 'Y'
  FROM [ScriptAssets]

GO

INSERT INTO [RaftItemVersions]
SELECT RI.[RaftItem_Id],
       [RaftItemVersion_Number] = ROW_NUMBER() OVER(PARTITION BY P.[Plan_Id] ORDER BY PV.[PlanVersion_Id]),
	   PV.[ModifiedOn_Date],
	   PV.[ModifiedBy_User_Name],
	   [Content_Bytes] = PV.[Plan_Bytes]

  FROM [RaftItems] RI
       INNER JOIN [Plans] P
	           ON (P.[Application_Id] = RI.[Application_Id] OR (P.[Application_Id] IS NULL AND RI.[Application_Id] IS NULL))
			  AND (CASE WHEN P.[PlanType_Code] = 'D' THEN 6 ELSE 3 END = RI.[RaftItemType_Code])
			  AND (P.[Plan_Name] = RI.[RaftItem_Name])
	   INNER JOIN [PlanVersions] PV
	           ON PV.[Plan_Id] = P.[Plan_Id]


GO

INSERT INTO [RaftItemVersions]
SELECT RI.[RaftItem_Id],
       [RaftItemVersion_Number] = 1,
	   [ModifiedOn_Date] = GETUTCDATE(),
	   [ModifiedBy_User_Name] = 'Anonymous',
	   [Content_Bytes] = TT.[Template_Bytes]
  FROM [RaftItems] RI
       INNER JOIN [TextTemplates] TT
	           ON (TT.[Application_Id] = RI.[Application_Id] OR (TT.[Application_Id] IS NULL AND RI.[Application_Id] IS NULL))
			  AND (TT.[Template_Name] = RI.[RaftItem_Name])
 WHERE RI.[RaftItemType_Code] = 7

GO

INSERT INTO [RaftItemVersions]
SELECT RI.[RaftItem_Id],
       [RaftItemVersion_Number] = 1,
	   P.[ModifiedOn_Date],
	   P.[ModifiedBy_User_Name],
	   [Content_Bytes] = CONVERT(varbinary(max), CONVERT(varchar(max),P.[Pipeline_Configuration]))
  FROM [RaftItems] RI
       INNER JOIN [Pipelines] P
	           ON (P.[Application_Id] = RI.[Application_Id] OR (P.[Application_Id] IS NULL AND RI.[Application_Id] IS NULL))
			  AND (P.[Pipeline_Name] = RI.[RaftItem_Name])
 WHERE RI.[RaftItemType_Code] = 8

GO

INSERT INTO [RaftItemVersions]
SELECT RI.[RaftItem_Id],
       [RaftItemVersion_Number] = 1,
	   SA.[ModifiedOn_Date],
	   SA.[ModifiedBy_User_Name],
	   [Content_Bytes] = SA.[Script_Text]
  FROM [RaftItems] RI
       INNER JOIN [ScriptAssets] SA
	           ON (SA.[Application_Id] = RI.[Application_Id] OR (RI.[Application_Id] IS NULL AND RI.[Application_Id] IS NULL))
			  AND (SA.[ScriptAsset_Name] = RI.[RaftItem_Name])
 WHERE RI.[RaftItemType_Code] = 4

GO

ALTER TABLE [Builds]
	ADD [Pipeline_Name] VARCHAR(100)

ALTER TABLE [Releases]
	ADD [Pipeline_Name] VARCHAR(100)

ALTER TABLE [RetentionPolicies]
	ADD [PurgeIn_Pipeline_Name] VARCHAR(100)

GO

UPDATE B
   SET [Pipeline_Name] = (CASE WHEN P.[Application_Id] IS NULL THEN 'global::' ELSE '' END) + P.[Pipeline_Name]
  FROM [Builds] B
       INNER JOIN [Pipelines] P
	           ON P.[Pipeline_Id] = B.[Pipeline_Id]

UPDATE R
   SET [Pipeline_Name] = (CASE WHEN P.[Application_Id] IS NULL THEN 'global::' ELSE '' END) + P.[Pipeline_Name]
  FROM [Releases] R
       INNER JOIN [Pipelines] P
	           ON P.[Pipeline_Id] = R.[Pipeline_Id]

UPDATE RP
   SET [PurgeIn_Pipeline_Name] = (CASE WHEN P.[Application_Id] IS NULL THEN 'global::' ELSE '' END) + P.[Pipeline_Name]
  FROM [RetentionPolicies] RP
       INNER JOIN [Pipelines] P
	           ON P.[Pipeline_Id] = RP.[PurgeIn_Pipeline_Id]

GO

ALTER TABLE [Builds]
	DROP CONSTRAINT [FK__Builds__Pipelines]
ALTER TABLE [Builds]
	DROP COLUMN [Pipeline_Id]

ALTER TABLE [Releases]
	DROP CONSTRAINT [FK__Releases__Pipelines]
ALTER TABLE [Releases]
	DROP COLUMN [Pipeline_Id]

ALTER TABLE [RetentionPolicies]
	DROP CONSTRAINT [FK__RetentionPolicies__Pipelines]
ALTER TABLE [RetentionPolicies]
	DROP COLUMN [PurgeIn_Pipeline_Id]

ALTER TABLE [Releases]
        DROP COLUMN [Original_Workflow_Name]

DROP TABLE [PlanVersions]
DROP TABLE [Plans]
DROP TABLE [TextTemplates]
DROP TABLE [ScriptAssets]
DROP TABLE [Pipelines]
