IF OBJECT_ID('[Executions_Related]') IS NOT NULL DROP VIEW [Executions_Related]
GO

CREATE VIEW [Executions_Related] AS

	SELECT E.[Execution_Id],
		   E.[Start_Date],
		   E.[End_Date],
		   E.[ExecutionRunState_Code],
		   E.[ExecutionStatus_Code],
           E.[ExecutionMode_Code],
		   E.[CreatedBy_User_Name],
		   E.[CreatedOn_Date],
		   E.[CanceledBy_User_Name],
		   E.[CanceledOn_Date],
		   ENV.[Environment_Id],
		   ENV.[Environment_Name],
		   BE.[PipelineStageTarget_Index],
		   [Plan_Name] = COALESCE(BE.[Plan_Name], BTE.[Plan_Name]),
		   BP.[PipelineStage_Name],
		   A.[Application_Id],
		   A.[Application_Name],
		   B.[Build_Id],
		   B.[Build_Number],
		   R.[Release_Id],
		   R.[Release_Number],
		   BP.[Promotion_Id],
		   [Release_Name] = COALESCE(R.[Release_Name], R.[Release_Number]),
		   [ManualExecutionType_Name] = ME.[ExecutionType_Name],
		   [ManualExecution_Configuration] = ME.[Execution_Configuration]

	  FROM [Executions] E
            LEFT JOIN [PipelineStageTargetExecutions] BE
		           ON E.[ExecutionMode_Code] = 'B' AND E.[Execution_Id] = BE.[Execution_Id]
			LEFT JOIN [PipelineStageDeploymentExecutions] PSDE
			       ON E.[ExecutionMode_Code] = 'S' AND PSDE.[Execution_Id] = E.[Execution_Id]
			LEFT JOIN [BuildTriggerExecutions] BTE
			       ON E.[ExecutionMode_Code] = 'T' AND BTE.[Execution_Id] = E.[Execution_Id]
			LEFT JOIN [ManualExecutions] ME
			       ON E.[ExecutionMode_Code] = 'M' AND ME.[Execution_Id] = E.[Execution_Id]
			LEFT JOIN [Environments] ENV
			       ON ENV.[Environment_Name] = BE.[Environment_Name]
			LEFT JOIN [BuildPromotions] BP
			       ON BP.[Promotion_Id] = PSDE.[Promotion_Id]
				   OR BP.[Promotion_Id] = BE.[Promotion_Id]
			LEFT JOIN [Builds] B
			       ON B.[Build_Id] = BP.[Build_Id]
			LEFT JOIN [Applications] A
			       ON A.[Application_Id] = B.[Application_Id]
				   OR A.[Application_Id] = BTE.[Application_Id]
			LEFT JOIN [Releases] R
			       ON B.[Release_Id] = R.[Release_Id]
                     
GO
