EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Releases_UnCancelRelease',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Restores a previously canceled release.'
GO

IF OBJECT_ID('[Releases_UnCancelRelease]') IS NOT NULL DROP PROCEDURE [Releases_UnCancelRelease]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Releases_UnCancelRelease]
(
	@Application_Id INT,
	@Release_Number RELEASENUMBER
) AS
BEGIN

	SET NOCOUNT ON

    DECLARE @Release_Id INT

    SELECT @Release_Id = [Release_Id] 
      FROM [Releases_Extended]
     WHERE [Application_Id] = @Application_Id
	   AND [Release_Number] = @Release_Number
	   AND [ReleaseStatus_Name] = 'Cancelled'

	IF @Release_Id IS NULL
	BEGIN
		RAISERROR('Release ''%s'' does not exist or its status is not ''Cancelled''', 16, 1, @Release_Number)
		RETURN
	END


BEGIN TRY
	BEGIN TRANSACTION

		UPDATE [Releases]
		   SET [ReleaseStatus_Name] = 'Active'
		  FROM [Releases] R 
		 WHERE [Release_Id] = @Release_Id

	EXEC [Events_RaiseEvent] 'RELMOD', @Application_Id, @Release_Number

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Releases_UnCancelRelease] TO [BuildMasterUser_Role]